@@ -16,7 +16,7 @@ task_name_list = [
 if 'milestone_4_p2.txt' in os.listdir('.'):
     errors = get_errors_fails('milestone_4_p2.txt')
     print(errors)
-    if len(errors) == 0:
+    if len(errors) != 0:
         for task in task_name_list:
             mark_complete(task[1])
     else:
